use std::sync::Arc;

use axum::{Extension, Json};
use eyre::{Result, Context};
use foxchat::http::ApiError;
use rsa::pkcs1::EncodeRsaPublicKey;
use serde::Serialize;

use crate::{app_state::AppState, model::instance::Instance};

pub async fn get_node(Extension(state): Extension<Arc<AppState>>) -> Result<Json<NodeResponse>, ApiError> {
    let instance = Instance::get(&state.pool).await?;

    let public_key = instance
        .public_key
        .to_pkcs1_pem(rsa::pkcs8::LineEnding::LF)
        .wrap_err("serializing public key")?;

    Ok(Json(NodeResponse {
        software: NODE_SOFTWARE,
        public_key,
    }))
}

const NODE_SOFTWARE: &str = "foxchat_ident";

#[derive(Serialize)]
pub struct NodeResponse {
    pub software: &'static str,
    pub public_key: String,
}
